==> knative-model-4.6.3-sources.jar: annotations/io/fabric8/knative/serving/v1alpha1/ServiceFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceFluent<A extends io.fabric8.knative.serving.v1alpha1.ServiceFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public ServiceFluent.MetadataNested<A> withNewMetadata();
    public ServiceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public ServiceFluent.MetadataNested<A> editMetadata();
    public ServiceFluent.MetadataNested<A> editOrNewMetadata();
    public ServiceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.serving.v1alpha1.ServiceSpec getSpec();
    public io.fabric8.knative.serving.v1alpha1.ServiceSpec buildSpec();
    public A withSpec(io.fabric8.knative.serving.v1alpha1.ServiceSpec spec);
    public Boolean hasSpec();
    public ServiceFluent.SpecNested<A> withNewSpec();
    public ServiceFluent.SpecNested<A> withNewSpecLike(io.fabric8.knative.serving.v1alpha1.ServiceSpec item);
    public ServiceFluent.SpecNested<A> editSpec();
    public ServiceFluent.SpecNested<A> editOrNewSpec();
    public ServiceFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.knative.serving.v1alpha1.ServiceSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.serving.v1alpha1.ServiceStatus getStatus();
    public io.fabric8.knative.serving.v1alpha1.ServiceStatus buildStatus();
    public A withStatus(io.fabric8.knative.serving.v1alpha1.ServiceStatus status);
    public Boolean hasStatus();
    public ServiceFluent.StatusNested<A> withNewStatus();
    public ServiceFluent.StatusNested<A> withNewStatusLike(io.fabric8.knative.serving.v1alpha1.ServiceStatus item);
    public ServiceFluent.StatusNested<A> editStatus();
    public ServiceFluent.StatusNested<A> editOrNewStatus();
    public ServiceFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.knative.serving.v1alpha1.ServiceStatus item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<ServiceFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.ServiceSpecFluent<ServiceFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.ServiceStatusFluent<ServiceFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> knative-model-4.9.2-sources.jar: annotations/io/fabric8/knative/serving/v1alpha1/ServiceFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceFluent<A extends io.fabric8.knative.serving.v1alpha1.ServiceFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public ServiceFluent.MetadataNested<A> withNewMetadata();
    public ServiceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public ServiceFluent.MetadataNested<A> editMetadata();
    public ServiceFluent.MetadataNested<A> editOrNewMetadata();
    public ServiceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public io.fabric8.knative.serving.v1alpha1.ServiceSpec getSpec();
    public io.fabric8.knative.serving.v1alpha1.ServiceSpec buildSpec();
    public A withSpec(io.fabric8.knative.serving.v1alpha1.ServiceSpec spec);
    public Boolean hasSpec();
    public ServiceFluent.SpecNested<A> withNewSpec();
    public ServiceFluent.SpecNested<A> withNewSpecLike(io.fabric8.knative.serving.v1alpha1.ServiceSpec item);
    public ServiceFluent.SpecNested<A> editSpec();
    public ServiceFluent.SpecNested<A> editOrNewSpec();
    public ServiceFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.knative.serving.v1alpha1.ServiceSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public io.fabric8.knative.serving.v1alpha1.ServiceStatus getStatus();
    public io.fabric8.knative.serving.v1alpha1.ServiceStatus buildStatus();
    public A withStatus(io.fabric8.knative.serving.v1alpha1.ServiceStatus status);
    public Boolean hasStatus();
    public ServiceFluent.StatusNested<A> withNewStatus();
    public ServiceFluent.StatusNested<A> withNewStatusLike(io.fabric8.knative.serving.v1alpha1.ServiceStatus item);
    public ServiceFluent.StatusNested<A> editStatus();
    public ServiceFluent.StatusNested<A> editOrNewStatus();
    public ServiceFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.knative.serving.v1alpha1.ServiceStatus item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<ServiceFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.ServiceSpecFluent<ServiceFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.ServiceStatusFluent<ServiceFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
